@@ -131,6 +131,7 @@ class webapp extends WAP_private
             'SELECT '.
                 'id,'.
                 'modify,'.
+                'ref_account,'.
                 'ref_diary,'.
                 'regist_date,'.
                 'visibility,'.
@@ -141,8 +142,7 @@ class webapp extends WAP_private
             'FROM '.
                 DB_PREFIX.'dia_entry '.
             'WHERE '.
-                'id = '.$this->id.' AND '.
-                'ref_account = '.$this->account['id'];
+                'id = '.$this->id;
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
         $result = $stmt->fetch(PDO_FETCH_ASSOC);
@@ -151,7 +151,13 @@ class webapp extends WAP_private
             header('Location: '.HTTP_ACTION.'private/diary/list/');
             exit();
         }
-        
+   
+        /* 他人の日記記事 */
+        if ($result['ref_account'] != $this->account['id']){
+            header('Location: '.HTTP_ACTION.'friend/diary/entry/'.$result['ref_account'].'/'.WAP_URI_SEPARATOR.'id='.$this->id);
+            exit();
+        }
+
         $this->ref_diary = $result['ref_diary'];
         $this->regist_date = $result['regist_date'];
 
