@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/02] カテゴリ選択更新時エラーを修正
  -      [2006/09/25] sns_dia_entry.link を更新しないように変更
  -      [2006/09/17] do_query_select()のforach() Warning を除去
  -      [2006/08/29] 日記カテゴリの取得エラーを修正
@@ -203,6 +204,8 @@ class webapp extends WAP_private
      */
     function format_body($string)
     {
+        $string = str_ireplace('<br>',"\r\n",$string);
+        $string = str_ireplace('<br />',"\r\n",$string);
         return strip_tags($string);
     }
 
@@ -228,9 +231,12 @@ class webapp extends WAP_private
         $this->objmnp->setValue('visibility', VISIBILITY_PROTECTED);
         $this->objmnp->setValue('format', DIARY_FORMAT_PLAIN);
 
-        /* 入力データの加工設定 */
+        /* 初期値への加工設定 */
         $func = array('webapp', 'format_body');
-        $this->objmnp->setInputEffect('body', array('func'=>$func, 'key'=>'body'));
+        $this->objmnp->setInitEffect('body', array('func'=>$func, 'key'=>'body'));
+
+        /* 入力データの加工設定 */
+        $this->objmnp->setInputEffect('body', array('func'=>'strip_tags'));
 
         // 更新しない項目名
         $skip = array(
@@ -414,6 +420,38 @@ class webapp extends WAP_private
         $this->Assign('categorys', $list);
     }
 
+    /**
+     * 選択済みカテゴリの取得
+     *
+     * @access private
+     * @return interger     データ操作結果
+     */
+    function get_selected()
+    {
+        $ref_entry = $this->objmnp->getCurID();
+        $select = array();
+        $sql=
+            'SELECT '.
+                'ref_category '.
+            'FROM '.
+                DB_PREFIX.'dia_select '.
+            'WHERE '.
+                'ref_diary ='.$this->ref_diary.' AND '.
+                'ref_entry ='.$ref_entry;
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
+        if (empty($result)){
+            return $select;
+        }
+        
+        foreach ($result as $value){
+            $select[$value['ref_category']] = $value['ref_category'];
+        }
+
+        return $select;
+    }
+
     /**
      * データ操作設定・実行
      *
@@ -423,6 +461,7 @@ class webapp extends WAP_private
     function do_query_select()
     {
         $ref_entry = $this->objmnp->getCurID();
+        $selected = $this->get_selected();
         $sql=
             'SELECT '.
                 'id '.
@@ -439,9 +478,13 @@ class webapp extends WAP_private
 
         foreach ($result as $value){
             if (empty($this->dia_select[$value['id']])){
-                $this->delete_select($value['id'], $ref_entry);
+                if (!empty($selected[$value['id']])){
+                    $this->delete_select($value['id'], $ref_entry);
+                }
             } else {
-                $this->insert_select($value['id'], $ref_entry);
+                if (empty($selected[$value['id']])){
+                    $this->insert_select($value['id'], $ref_entry);
+                }
             }
         } // foreach ($result as $value)
 
