@@ -21,6 +21,8 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/02] 本文の初期値、改行部分を修正
+ -      [2007/02/02] カテゴリ選択更新時エラーを修正
  -      [2006/09/25] sns_dia_entry.link を更新しないように変更
  -      [2006/09/17] do_query_select()のforach() Warning を除去
  -      [2006/08/29] 日記カテゴリの取得エラーを修正
@@ -87,6 +89,7 @@ class webapp extends WAP_private
         $this->addCss('crosseditor.css');
         $this->addJavas('prototype.js');
         $this->addJavas('crosseditor.js');
+        $this->set_crosseditor();
 
         /* URL引数の取得 */
         $this->setSafety('id');
@@ -148,7 +151,6 @@ class webapp extends WAP_private
         $objmenu = new dia_menu($this,$this->account['id']);
         $objmenu->setMenu($this->account['id']);
 
-        $this->set_crosseditor();
         $this->set_category();
         $this->Assign('picture', $objpic->getImgInfos());
     }
@@ -161,6 +163,9 @@ class webapp extends WAP_private
      */
     function set_crosseditor()
     {
+        if (preg_match('/confirm/i',$_SERVER['REQUEST_URI'])){
+            return ;
+        }
         $img = BASE_URL.'resource/img/crosseditor/';
 
         $init = 
@@ -237,26 +242,44 @@ class webapp extends WAP_private
      */
     function format_body($string)
     {
-        $string = str_replace('<p>', '', $string);
-        $string = str_replace('</p>', '<br />', $string);
+        $string = str_ireplace('<p>', '', $string);
+        $string = str_ireplace('</p>', '<br />', $string);
 
-        $string = str_replace('<div>', '', $string);
-        $string = str_replace('</div>', '<br />', $string);
+        $string = str_ireplace('<div>', '', $string);
+        $string = str_ireplace('</div>', '<br />', $string);
 
         return $string;
     }
 
     /**
-     * <br />タグの削除
+     * 初期値への加工設定
      *
-     * @access public
-     * @param string $value
-     * @return string
+     * @access private
+     * @return interger     データ操作結果
      */
-    function replace_br($string)
+    function init_effect()
     {
-        $string = str_replace('<br />', '', $string);
-        return $string;
+        $sql=
+            'SELECT '.
+                'format '.
+            'FROM '.
+                DB_PREFIX.'dia_entry '.
+            'WHERE '.
+                'id ='.$this->id;
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetch(PDO_FETCH_ASSOC);
+        $stmt->closeCursor();
+
+        if (empty($result)){
+            return ;
+        }
+        if ($result['format'] != DIARY_FORMAT_PLAIN){
+            return ;
+        }
+
+        /* 初期値への加工設定 */
+        $this->objmnp->setInitEffect('body', array('func'=>'nl2br'));
     }
 
     /**
@@ -270,6 +293,7 @@ class webapp extends WAP_private
         // 新規登録以外の処理
         if (!empty($this->id)){
             $this->objmnp->setCurID($this->id);
+            $this->init_effect();
         } else {
             $this->objmnp->setValue('ref_account', $this->account['id']);
             $this->objmnp->setValue('regist_date', date('Y-m-d H:i:s'));
@@ -281,10 +305,6 @@ class webapp extends WAP_private
         $this->objmnp->setValue('visibility', VISIBILITY_PROTECTED);
         $this->objmnp->setValue('format', DIARY_FORMAT_HTML);
 
-        /* 初期値への加工設定 */
-        $func = array('webapp', 'replace_br');
-        $this->objmnp->setInitEffect('body', array('func'=>$func, 'key'=>'body'));
-
         /* 入力データの加工設定 */
         $func = array('webapp', 'format_body');
         $this->objmnp->setInputEffect('body', array('func'=>$func, 'key'=>'body'));
@@ -471,6 +491,38 @@ class webapp extends WAP_private
         $this->Assign('categorys', $list);
     }
 
+    /**
+     * 選択済みカテゴリの取得
+     *
+     * @access private
+     * @return interger     データ操作結果
+     */
+    function get_selected()
+    {
+        $ref_entry = $this->objmnp->getCurID();
+        $select = array();
+        $sql=
+            'SELECT '.
+                'ref_category '.
+            'FROM '.
+                DB_PREFIX.'dia_select '.
+            'WHERE '.
+                'ref_diary ='.$this->ref_diary.' AND '.
+                'ref_entry ='.$ref_entry;
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
+        if (empty($result)){
+            return $select;
+        }
+        
+        foreach ($result as $value){
+            $select[$value['ref_category']] = $value['ref_category'];
+        }
+
+        return $select;
+    }
+
     /**
      * データ操作設定・実行
      *
@@ -480,6 +532,7 @@ class webapp extends WAP_private
     function do_query_select()
     {
         $ref_entry = $this->objmnp->getCurID();
+        $selected = $this->get_selected();
         $sql=
             'SELECT '.
                 'id '.
@@ -496,9 +549,13 @@ class webapp extends WAP_private
 
         foreach ($result as $value){
             if (empty($this->dia_select[$value['id']])){
-                $this->delete_select($value['id'], $ref_entry);
+                if (!empty($selected[$value['id']])){
+                    $this->delete_select($value['id'], $ref_entry);
+                }
             } else {
-                $this->insert_select($value['id'], $ref_entry);
+                if (empty($selected[$value['id']])){
+                    $this->insert_select($value['id'], $ref_entry);
+                }
             }
         } // foreach ($result as $value)
 
