@@ -289,9 +289,7 @@ class webapp extends WAP_private
         $objmail->Assign('user_name', $user['nickname']);
         $objmail->Assign('url', HTTP_ACTION.'friend/show/profile/'.$this->account['id'].'/');
 
-        $crypt = RKT_crypt::getInstance();
-        $to = $crypt->decrypt($user['email']);
-        
+        $to = sql_query::decrypt($user['email']);        
         $objmail->send($to);
     }
 
@@ -364,7 +362,7 @@ class webapp extends WAP_private
                 DB_PREFIX.'com_community com,'.
                 DB_PREFIX.'com_names nam '.
             'WHERE '.
-                'act.id = nam.ref_account AND '.
+                'act.id = com.ref_account AND '.
                 'act.id = pro.ref_account AND '.
                 'com.id = nam.ref_community AND '.
                 'act.avail = '.AVAIL_ENABLE.' AND '.
@@ -444,9 +442,7 @@ class webapp extends WAP_private
         $objmail->Assign('result', $result);
         $objmail->Assign('url', HTTP_ACTION.'community/show/community/'.$infos['id'].'/');
 
-        $crypt = RKT_crypt::getInstance();
-        $to = $crypt->decrypt($infos['email']);
-        
+        $to = sql_query::decrypt($infos['email']);        
         $objmail->send($to);
     }
 
@@ -573,9 +569,7 @@ class webapp extends WAP_private
         $objmail->Assign('community', $infos['community']);
         $objmail->Assign('url', HTTP_ACTION.'community/show/community/'.$infos['id'].'/');
 
-        $crypt = RKT_crypt::getInstance();
-        $to = $crypt->decrypt($infos['email']);
-
+        $to = sql_query::decrypt($infos['email']);
         $objmail->send($to);
     }
 } // webapp
