@@ -46,6 +46,12 @@ class webapp extends WAP_private
      */
     var $objmnp = null;
 
+    /**
+     * スケジュールリスト
+     * @var string
+     */
+    var $term = '';
+
     /**
      * 実行処理
      *
@@ -58,12 +64,16 @@ class webapp extends WAP_private
 
         $this->setTemplateFile('private/home/home.tpl');
 
+        $timestamp = strtotime(TERM_MYHOME_NEWS);
+        $this->term = $this->objdb->quote(date('Y-m-d H:i:s', $timestamp));
+
         $this->set_info();
 
         $this->set_friend_relation();
         $this->set_admin_change();
         $this->set_community_entry();
         $this->set_new_message();
+        $this->set_new_comment();
 
         $this->set_today();
         $this->set_friend();
@@ -210,6 +220,32 @@ class webapp extends WAP_private
         $this->Assign('new_message', $result['ct']);
     }
 
+    /**
+     * 未読コメントの設定
+     *
+     * @access private
+     * @return void
+     */
+    function set_new_comment()
+    {
+        $sql=
+            'SELECT '.
+                'count(*) as ct '.
+            'FROM '.
+                DB_PREFIX.'dia_diary dia,'.
+                DB_PREFIX.'dia_comment cmt '.
+            'WHERE '.
+                'dia.id = cmt.ref_diary AND '.
+                'cmt.flag = '.MESSAGE_FLAG_UNREAD.' AND '.
+                'dia.ref_account = '.$this->account['id'];
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetch(PDO_FETCH_ASSOC);
+        $stmt->closeCursor();
+
+        $this->Assign('new_comment', $result['ct']);
+    }
+
     /**
      * 今日の日付の設定
      *
@@ -431,7 +467,8 @@ class webapp extends WAP_private
                 'ent.id = com.ref_entry AND '.
                 'act.avail = '.AVAIL_ENABLE.' AND '.
                 'dia.ref_account != '.$this->account['id'].' AND '.
-                'com.ref_account = '.$this->account['id'].' '.
+                'com.ref_account = '.$this->account['id'].' AND '.
+                'com.modify > '.$this->term.' '.
             'GROUP BY '.
                 'act.id,'.
                 'dia.id,'.
@@ -475,6 +512,7 @@ class webapp extends WAP_private
                 'com.id = nam.ref_community AND '.
                 'com.id = tpc.ref_community AND '.
                 'com.avail = '.AVAIL_ENABLE.' AND '.
+                'tpc.modify > '.$this->term.' AND '.
                 'nam.ref_account = '.$this->account['id'].' AND '.
                 'nam.status != '.STATUS_COMMUNITY_REFUSAL.' AND '.
                 'nam.status != '.STATUS_COMMUNITY_REQUEST.' '.
@@ -523,6 +561,7 @@ class webapp extends WAP_private
                 'act.id = dia.ref_account AND '.
                 'dia.id = ent.ref_diary AND '.
                 'act.id = ent.ref_account AND '.
+                'ent.regist_date > '.$this->term.' AND '.
                 'act.avail = '.AVAIL_ENABLE.' AND '.
                 'fri.avail = '.AVAIL_ENABLE.' AND '.
                 'fri.status = '.STATUS_FRIEND_CONNECT.' AND '.
@@ -556,6 +595,7 @@ class webapp extends WAP_private
                 DB_PREFIX.'frm_topic '.
             'WHERE '.
                 'ref_account = '.$this->account['id'].' AND '.
+                'modify > '.$this->term.' AND '.
                 'visibility != '.VISIBILITY_HIDDEN.' '.
             'ORDER BY '.
                 'modify DESC '.
@@ -630,6 +670,7 @@ class webapp extends WAP_private
                 'act.id = dia.ref_account AND '.
                 'dia.id = ent.ref_diary AND '.
                 'ent.id = com.ref_entry AND '.
+                'com.modify > '.$this->term.' AND '.
                 'act.avail = '.AVAIL_ENABLE.' AND '.
                 'dia.ref_account = '.$this->account['id'].' '.
             'GROUP BY '.
