@@ -114,6 +114,34 @@ class webapp extends WAP_private
         return !empty($result['ct']);
     }
 
+    /**
+     * 入力されたメールの人が会員か？
+     *
+     * @access private
+     * @return boolean 正常時：真
+     */
+    function registered()
+    {
+        if (empty($_POST['email'])){
+            return false;
+        }
+
+        $email_hash = sql_query::hash(@$_POST['email']);
+        $sql=
+            'SELECT '.
+                'ref_friend '.
+            'FROM '.
+                DB_PREFIX.'fri_invite '.
+            'WHERE '.
+                "email_hash = '".$email_hash."'";
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetch(PDO_FETCH_ASSOC);
+        $stmt->closeCursor();
+
+        return !empty($result['ref_friend']);
+    }
+
     /**
      * IDの取得と設定
      *
@@ -132,7 +160,6 @@ class webapp extends WAP_private
             'FROM '.
                 DB_PREFIX.'fri_invite '.
             'WHERE '.
-                'ref_account = '.$this->account['id'].' AND '.
                 "email_hash ='".$email_hash."'";
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
@@ -160,6 +187,10 @@ class webapp extends WAP_private
             if ($this->is_member()){
                 $this->objmnp->setAlert('member');
             }
+            // メールの人が会員か？
+            if ($this->registered()){
+                $this->objmnp->setAlert('member');
+            }
             /* 招待メール */
             $this->objmnp->setInput('email', array('type'=>'email', 'required'=>true));
 
